# Changelog

## [0.2.0](https://github.com/numb86/dbt-pal/compare/v0.1.0...v0.2.0) (2026-02-14)


### Features

* allow Python models to import local modules from project root ([#8](https://github.com/numb86/dbt-pal/issues/8)) ([fae51f9](https://github.com/numb86/dbt-pal/commit/fae51f92620b5a4cecd36fe84a931b60f22c6ee2))
* raise error when db_profile uses unsupported adapter type ([#2](https://github.com/numb86/dbt-pal/issues/2)) ([ee0a118](https://github.com/numb86/dbt-pal/commit/ee0a118a2baf8633cd4059e512d0dd3eff5c823e))


### Bug Fixes

* replace assert with ValueError ([#4](https://github.com/numb86/dbt-pal/issues/4)) ([fc0e6df](https://github.com/numb86/dbt-pal/commit/fc0e6dfe358ff3a449c596686d8d040217a18354))
